==> fwobac-1.2.tar.gz: fwobac-1.2/rhf.h <==
/* $Id: rhf.h,v 1.4 2017/08/05 12:23:43 rlr Exp $ */

/*
 * Copyright (c) 2001, 2017 Ross L Richardson <ross@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/* Module providing functions for restricted HTML fragments. */

#ifndef _RHF_H_
#define _RHF_H_


#include <stddef.h>
#include <stdio.h>


/* Status codes for rhf_validate(). */
#define RHF_OK                       0
#define RHF_SYNTAX_ERR               1
#define RHF_CHAR_REF_REQ             2
#define RHF_UNKNOWN_CHAR_REF         3
#define RHF_UNCLOSED_TAG             4
#define RHF_UNKNOWN_ELEMENT          5
#define RHF_INVAL_CLOSE_ELEMENT      6
#define RHF_UNBAL_CLOSE_ELEMENT      7
#define RHF_NONMATCH_CLOSE_ELEMENT   8
#define RHF_UNBAL_OPEN_ELEMENT       9
#define RHF_BAD_HIER                10
#define RHF_EMPTY_ANCHOR            11
#define RHF_BAD_ATTR                12
#define RHF_MISSING_ATTR            13
#define RHF_ATTR_NOT_PERM           14

/*
 * void	 rhf_validate(const char *m, int *status, size_t *pos);
 *
 * Validates the HTML fragment m according to the following restrictions:
 * - the only elements permitted are
 *     - <a>/</a>
 *     - <b>/</b>
 *     - <br>
 *     - <em>/</em>
 *     - <i>/</i>
 *     - <p>[/</p>]
 *     - <pre>/</pre>
 *     - <strong>/</strong>
 * - element <a> must have an href attribute (with value), but no other
 *   attributes are permitted
 * - the only character references permitted are "&amp;", "&gt;", "&lt;",
 *   and "&quot;", and these must be used (for '&', '>', '<', and '"',
 *   respectively) in all non-markup text and in the value of the href
 *   attribute
 * - the empty string is considered valid
 *
 * m must be non-NULL.  If m is valid, *status is set to RHF_OK and *pos to the
 * length of m; otherwise, *status contains an appropriate error code and *pos
 * indicates the location at which the error was detected (which may be later
 * than the error).
 */
void	 rhf_validate(const char *, int *, size_t *);


/*
 * void	 html_print_cleansed(FILE *f, const char *s, const char *inj_a);
 *
 * f must be non-NULL and valid.  s must refer to a valid HTML document or,
 * at least, a fragment found valid by html_is_valid_restricted_fragment().
 * Prints to f a the equivalent of s with:
 * - HTML markup converted (if necessary) to lower case
 * - unnecessary whitespace elided from HTML markup
 * - if inj_a is non-NULL, a space character and inj_a inserted in the output
 *   before the closing '>' of each '<a>'
 */
void	 rhf_print_cleansed(FILE *, const char *, const char *);


#endif /* !_RHF_H_ */

==> fwobac-2.1.tar.gz: fwobac-2.1/rhf.h <==
/* $Id: rhf.h,v 1.7 2018/06/19 04:51:01 rlr Exp $ */

/*
 * Copyright (c) 2001, 2017, 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/* Module providing functions for restricted HTML fragments. */

#ifndef _RHF_H_
#define _RHF_H_


#include <stddef.h>
#include <stdio.h>


/* Status codes for rhf_validate(). */
#define RHF_OK                       0
#define RHF_SYNTAX_ERR               1
#define RHF_CHAR_REF_REQ             2
#define RHF_UNKNOWN_CHAR_REF         3
#define RHF_UNCLOSED_TAG             4
#define RHF_UNKNOWN_ELEMENT          5
#define RHF_INVAL_CLOSE_ELEMENT      6
#define RHF_UNBAL_CLOSE_ELEMENT      7
#define RHF_NONMATCH_CLOSE_ELEMENT   8
#define RHF_UNBAL_OPEN_ELEMENT       9
#define RHF_BAD_HIER                10
#define RHF_EMPTY_ANCHOR            11
#define RHF_BAD_ATTR                12
#define RHF_MISSING_ATTR            13
#define RHF_ATTR_NOT_PERM           14

/*
 * void
 * rhf_validate(const char *m, int *status, size_t *pos);
 *
 * Validates the HTML fragment m according to the following restrictions:
 * - the only elements permitted are
 *     - <a>/</a>
 *     - <b>/</b>
 *     - <br>
 *     - <em>/</em>
 *     - <i>/</i>
 *     - <p>[/</p>]
 *     - <pre>/</pre>
 *     - <strong>/</strong>
 * - element <a> must have an href attribute (with value), but no other
 *   attributes are permitted
 * - the only character references permitted are "&amp;", "&gt;", "&lt;",
 *   and "&quot;", and these must be used (for '&', '>', '<', and '"',
 *   respectively) in all non-markup text and in the value of the href
 *   attribute
 * - the empty string is considered valid
 *
 * m must be non-NULL.  If m is valid, *status is set to RHF_OK and *pos to the
 * length of m; otherwise, *status contains an appropriate error code and *pos
 * indicates the location at which the error was detected (which may be later
 * than the error).
 */
void	 rhf_validate(const char *, int *, size_t *);


/*
 * void
 * html_print_cleansed(FILE *f, const char *s, const char *inj_a);
 *
 * f must be non-NULL and valid.  s must refer to a valid HTML document or,
 * at least, a fragment found valid by html_is_valid_restricted_fragment().
 * Prints to f a the equivalent of s with:
 * - HTML markup converted (if necessary) to lower case
 * - unnecessary whitespace elided from HTML markup
 * - if inj_a is non-NULL, a space character and inj_a inserted in the output
 *   before the closing '>' of each '<a>'
 */
void	 rhf_print_cleansed(FILE *, const char *, const char *);


#endif /* !_RHF_H_ */
